#!/bin/bash
#
# repair a damaged gentoo OS (the mirrored boot & root)
# http://www.gentoo.org/proj/en/base/x86/chroot.xml
#
# NOTE: the chroot environment does not mount all the normal fstab mounted disks (unless *you* mount them) 
# eg warehouse will not be mounted in the chroot so don't put PORTAGE_TMPDIR here
#


# $1 - the chroot (dir, trailing slash)
#
checkLinuxOs()
{
    local root="$1"
    local d

    for d in proc dev tmp
    do
         if [ ! -d ${root}${d} ]
         then
             ls -avlh $root
             echo "error: could not find [$d] in [$root]"
             echo "is [$root] a linux OS filesystem?"
             exit 1
         fi
    done
}

prepMirrors()
{
    mount $inactive_root_partition $gentool_mirror_mount_point
    mount $inactive_boot_partition ${gentool_mirror_mount_point}'/boot'
}

#
# $1 - the chroot (dir, trailing slash)
#
doChrootStuff() 
{
    local root="$1"

    checkLinuxOs $root
    mount -t proc none ${root}'proc'
    mount -o bind /dev ${root}'dev'    
    mount -o bind /tmp ${root}'tmp'
    mount -o bind /dev/pts ${root}'dev/pts'
    cp -L /etc/resolv.conf ${root}'etc/resolv.conf'
    
    # is this really needed?
    #cp ~'/.Xauthority' ${root}${1}'/'
    #cp ~'/.xauth'* ${root}${1}'/'
}

clearUp()
{
    local mounts=(
      ${gentool_mirror_mount_point}'/dev/pts' 
      ${gentool_mirror_mount_point}'/dev' 
      ${gentool_mirror_mount_point}'/proc' 
      ${gentool_mirror_mount_point}'/tmp' 
      ${gentool_mirror_mount_point}'/boot'
      ${gentool_mirror_mount_point}'/' 
    )
    local m
    
    for m in ${mounts[@]}
    do
            umount $m
    done
}

prepMirrors
doChrootStuff ${gentool_mirror_mount_point}'/'
echo 
echo '-----------------------------------------'
echo 'After chroot, run the following command:'
echo '-----------------------------------------'
echo 'env-update && source /etc/profile && export PS1="MIRROR $PS1" && grep -v rootfs /proc/mounts > /etc/mtab && export DISPLAY=":0.0"'
echo '-----------------------------------------'
echo 'Finally, exit the chroot by typing "exit"'
echo '-----------------------------------------'
echo 
echo 'OK chroot so run above commands now...'
echo
chroot $gentool_mirror_mount_point /bin/bash
echo
echo 'chroot done.'
echo
clearUp
