#!/bin/bash
#
# -------------------------------------------------

sources=(
    /etc/gentool/config.sh
    /etc/env.d/99gentool-env #!! don't need to source this except in testing
    /opt/gentool/lib/fns.sh
    /opt/bashfun/disk.sh
    /opt/bashfun/rsync.sh
    /opt/bashfun/interactive.sh
)
for s in ${sources[@]}
do
    source $s
    if [ $? -gt 0 ]
    then
        echo 'could not source file ['${s}']'
    	exit 1
    fi
done

# -------------------------------------------------

executables_dir='/opt/gentool/bin/'
active_boot_partition=`getPartitionAttachedTo /boot /etc/fstab`
active_root_partition=`getPartitionAttachedTo / /etc/fstab`
inactive_boot_partition=`getTheOtherOne "$active_boot_partition" "$boot_partition_A" "$boot_partition_B"`
inactive_root_partition=`getTheOtherOne "$active_root_partition"  "$root_partition_A" "$root_partition_B"`
active_boot_grub_partition_number=`getGrubNumber "$active_boot_partition"`
inactive_boot_grub_partition_number=`getGrubNumber "$inactive_boot_partition"`
active_boot=`echo $active_boot_partition | grep -Pow [^/]+$`
active_root=`echo $active_root_partition | grep -Pow [^/]+$`
inactive_boot=`echo $inactive_boot_partition | grep -Pow [^/]+$`
inactive_root=`echo $inactive_root_partition | grep -Pow [^/]+$`

root_excludes=`echo ${root_excludes[@]}`
rebuild_filesystem=`echo ${rebuild_filesystem[@]}`
my_mount_points=`echo ${my_mount_points[@]}`
copy_on_switch=`echo ${copy_on_switch[@]}`
all_root_excludes=`echo ${root_excludes[@]}" "${rebuild_filesystem[@]}" "${my_mount_points[@]}`

root_backup_policy=" -hivptgoDElHrSRx --delete --delete-excluded "`getExcludeClause "$all_root_excludes"`
boot_backup_policy=" -hivptgoDElHrSx --delete --delete-excluded"
empty_dir_policy='-hivptgoDElHSdRx -f"+ */" -f"- *"'
specials_policy=' -hivptgoDElHrS --delete --delete-excluded'
copy_on_switch_policy=' -hivptgoDElHrSRx --delete --delete-excluded'


export active_boot active_root active_boot_grub_partition_number active_boot_partition active_root_partition all_root_excludes boot_backup_policy copy_on_switch copy_on_switch_policy empty_dir_policy executables_dir gentool_mirror_mount_point inactive_boot inactive_root inactive_boot_grub_partition_number inactive_boot_partition inactive_root_partition my_mount_points rebuild_filesystem root_backup_policy root_excludes specials_policy

#--------------------------------------------------

gentoolSanityChecks $#

case $1 in

    find    )
                search='*'`echo $2 | sed 's/-/\*/g'`'*'
                equery list -i -o -p $search
            ;;

    sync     ) 
                   layman -S && emerge --sync && emerge -puND world
                    ;;
    copy     ) 
                   if [ -f /root/.gentool/pre-copy.sh ] 
                   then
                       bash /root/.gentool/pre-copy.sh
                   fi
                   bash ${executables_dir}'copy.sh' $@
                    ;;
    tar     )
                   bash ${executables_dir}'tar.sh' $@
                    ;;
    switch     ) 
                   if [ -f /root/.gentool/pre-switch.sh ] 
                   then
                       bash /root/.gentool/pre-switch.sh
                   fi
                   bash ${executables_dir}'switch.sh' $@
                    ;;
    mount     ) 
                   bash ${executables_dir}'mount-inactive-partitions.sh' $@
                    ;;
    umount    ) 
                   bash ${executables_dir}'unmount-inactive-partitions.sh' $@
                    ;;
    unmount    ) 
                   bash ${executables_dir}'unmount-inactive-partitions.sh' $@
                    ;;
    info     ) 
                   bash ${executables_dir}'info.sh' $@
                    ;;
    kernel     ) 
                   bash ${executables_dir}'kernel-builder.sh' $@
                    ;;
    chroot     ) 
                   bash ${executables_dir}'chroot.sh' $@
                    ;;
    clock     ) 
                   bash ${executables_dir}'setclock.sh' $@
                    ;;
    backup     ) 
                   bash ${executables_dir}'backup.sh' $@
                    ;;
    script     ) 
                   bash ${executables_dir}'script.sh' $@
                    ;;
    *          ) 
                    showHelp
                    ;;
esac

exit 0
