checkKernelSymlink()
{
    echo
    eselect kernel list
    echo
    echo 'Please check if the correct kernel sources are symlinked.'
    echo
    echo 'Press any key to continue....'
    echo
    echo 'Or CTRL+C to close this program and change with:'
    echo '$ eselect kernel list'
    echo '$ eselect kernel set $i'
    echo
    pause
    return 0
}

setKernelName()
{
    kernel=`getKernelVersion`
    echo
    echo "You can type a name for the new kernel here."
    echo "Or just hit enter to choose [$kernel]."

    read reply
    if [ "$reply" ]
    then
        kernel=$reply
    fi
    return 0
}

getKernelVersion()
{
    local resolved=`pwd -P`
    echo `basename $resolved | sed s/linux/kernel/`
    return 0
}

configureKernel()
{
    local prompt=$'\n'\
' '$'\n'\
'(1) Type "copy" and hit enter to copy the config for the currently running kernel.'$'\n'\
'    The following commands will be run:'$'\n'\
'    $ zcat /proc/config.gz > /usr/src/linux/.config'$'\n'\
'    $ make oldconfig'$'\n'\
'    $ make menuconfig'$'\n'\
'(2) Type "menu" and hit enter for make menuconfig.'$'\n'\
'    The following commands will be run:'$'\n'\
'    $ make menuconfig'$'\n'

    getValidInput "$prompt" 'configOptions'
    return 0
}
#
# $1 - menu or copy
#
configOptions()
{
    if [ -f .config ]
    then
        cp .config .config-`date +%s`
    fi
    case "$1" in
        "copy" )  zcat '/proc/config.gz' > '.config'
                  make oldconfig
                  make menuconfig
                  return 0
              ;;
        "menu" )  make menuconfig
                  return 0
              ;;
             * )  echo 
                  echo 'You did not select a valid option.'
                  echo 
                  return 1
              ;;
    esac
}

makeEverything() 
{
    #!! always ensure modules are rebuilt? or just make clean?
    # rm -r /lib/modules/$(uname -r)/*
    make clean 
    make modules 
    make bzImage 
    make modules_install
    update-modules
    return 0
}

rebuildModules()
{
    moduleRebuilder
    rebuildWhenNewKernel # user-defined
    moduleUpdater
    return 0
}

moduleRebuilder()
{
    echo 'Looking for modules to rebuild...'
    module-rebuild list
    if [ "$?" -eq 0 ]
    then
        module-rebuild rebuild
    else
        echo 'no modules to rebuild'
        return 0
    fi
}

moduleUpdater()
{
    echo 'If loadable modules have changed, you must edit /etc/modules.autoload.d/kernel-2.6.'
    echo 'If necessary, open another terminal now and make the changes.'
    echo 'Press any key to continue...'
    pause
    update-modules
    return 0
}

copyToBoot()
{
    mount /boot
    cp $bzpath '/boot/'${kernel}
    cp System.map /boot/System.map-${kernel}
    cp .config /boot/config-${kernel}
}

checkGrub()
{
    if [ "`cat /boot/grub/grub.conf | grep $kernel`" ]    
    then
        umount /boot
    else
        pleaseEditGrubConf
        pause
        umount /boot
    fi
    return 0
}

#!! multiple kernel support..? framebuffer/none options?
pleaseEditGrubConf() 
{
    local message=$'\n'\
"Could not find an entry for the newly compiled kernel [$kernel] in [/boot/grub/grub.conf]"$'\n'\
'Please edit grub.conf then hit any key to continue...'$'\n'\
$'\n'\

    echo "$message"
    return 0
}
