#
# make an exact copy (perms etc) of a dir but not the dir contents
# if a file gets into the list by mistake it will be ignored
#
# $1 - rsync dest dir; trailing slash agnostic
#
rebuildFilesystem()
{
    local dirs 
    local dir
    local dest

    dest=`oneEndSlash "$1"`

    echo 'rebuilding filesystem'
    
    if [ "" = "$dest" ]
    then
        echo 'no value for rebuildFilesystem $dest'
        exit 1
    fi
    if [ 'true' = $is_pretending ]
    then
        echo '$empty_dir_policy: '$empty_dir_policy
    fi

    for dir in $all_root_excludes
    do
        echo "copying [$dir] to ["${dest}"] (dir only)"
        if [[ 'true' != $is_pretending && ! -d "$dir" ]]
        then
            mkdir $dir
        fi
        eval rsync $empty_dir_policy $dir ${dest}

        if [ $? -gt 0 ]
        then
            echo "#!! ERROR [$?] when copying [$dir] to ["${dest}"]"
        fi 
    done
    return 0
}

#
# /dev/null and /dev/console
#
# $1 - rsync dest dir; trailing slash agnostic
#
copySpecialFiles()
{
    local dest
    local path
    local acccount

    dest=`stripEndSlash "$1"`

    if [ "true" = $is_pretending ]
    then
        return
    fi

    if [ "" = "$dest" ]
    then
        echo 'no value for copySpecialFiles $dest'
        exit 1
    fi

    path=`echo "$dest" | sed 's-^[^@]*@[^:]*:--g'`
    
    # no foo@bar: component - hence local path
    if [ "$path" = "$dest" ]
    then
        pwd=$PWD
        cd ${dest}'/dev'
        mknod -m 660 console c 5 1
        mknod -m 660 null c 1 3
        cd $pwd

    # network path
    else
        eval rsync $root_backup_policy /dev/console ${dest}
        eval rsync $root_backup_policy /dev/null ${dest}
    fi

    return 0
}

#
# backup OS and apps
# will preserve permissions et al so that the backup is bootable
# will ignore unneeded dirs such as /tmp
#
copySystem() {
    local root="$1"
    local dest="$2"
    local should_pretend="$3"
    
    # 1st pass: rsync with exclusions
    rsyncw "$1" "$2" "$software_policy" "$3"

    # 2nd pass: rebuild filesystem where necessary (excluded dirs, special files)
    rebuildFilesystem "$2" "$3"
    copySpecialFiles "$2" "$3"
}
